Config

Struct Config 

pub struct Config {
    pub max_msg_size: usize,
    pub skip_up_timeout: Option<Duration>,
    pub max_resident_credential_count: Option<u32>,
    pub large_blobs: Option<Config>,
    pub nfc_transport: bool,
}
Externally defined configuration.

Fields

max_msg_size: usize

Typically determined by surrounding USB-level decoder. For Solo 2, this is usbd-ctaphid (and its buffer size).

skip_up_timeout: Option<Duration>

If set, the first Get Assertion or Authenticate request within the specified time after boot is accepted without additional user presence verification.

max_resident_credential_count: Option<u32>

The maximum number of resident credentials.

large_blobs: Option<Config>

Configuration for the largeBlobKey extension and the largeBlobs command.

If this is None, the extension and the command are disabled.

nfc_transport: bool

Whether the authenticator supports the NFC transport.

Implementations