LargeBlobsConfig

Struct LargeBlobsConfig 

pub struct LargeBlobsConfig {
    pub location: Location,
    pub max_size: usize,
}

Fields

location: Location

The location for storing the large-blob array.

max_size: usize

The maximum size for the large-blob array including metadata.

This value must be at least 1024 according to the CTAP2.1 spec. Without the chunking extension, it cannot be larger than 1024 because the large-blob array must fit into a Trussed message. Therefore, this setting is only available if the chunked feature is enabled.

Implementations

Source

impl Config

pub fn max_size(&self) -> usize